//
//  Bardecode.h
//  iBardecode
//
//  Copyright 2010 Softek Software Ltd. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#include "barcode.h"

#if TARGET_IPHONE_SIMULATOR
@interface Bardecode : NSObject <UINavigationControllerDelegate, UIImagePickerControllerDelegate>
#else
@interface Bardecode : NSObject <UINavigationControllerDelegate, UIImagePickerControllerDelegate, AVCaptureVideoDataOutputSampleBufferDelegate>
#endif
{
	// Public properties of the Softek Barcode Reader SDK
	bool AllowDuplicateValues;
	int BitmapResolution;
	int CodabarMaxVariance;
	bool Code25Checksum;
	bool Code39Checksum;
	bool Code39NeedStartStop;
	int ColorChunks;
	int ColorProcessingLevel;
	int ColorThreshold;
	bool ConvertUPCEToEAN13;
	int DatabarOptions;
	bool Despeckle;
	int Encoding;
	bool ErrorCorrection;
	bool ExtendedCode39;
	int GammaCorrection;
	NSString *LicenseKey;
	int LineJump ;
	int MaxLength;
	bool MedianFilter;
	int MinLength;
	int MinOccurrence ;
	int MinSpaceBarWidth;
	bool MultipleRead;
	bool NoiseReduction;
	int PageNo;
	int PatchCodeMinOccurrence;
	NSString *Pattern;
	bool Pdf417Debug;
	int Photometric;
	int PrefOccurrence ;
	int QuietZoneSize;
	bool ReadCodabar ;
	bool ReadCode128 ;
	bool ReadCode25 ;
	bool ReadCode25ni;
	bool ReadCode39 ;
	bool ReadCode93;
	bool ReadDatabar ;
	bool ReadDatamatrix ;
	bool ReadQRCode ;
	bool ReadEAN13 ;
	bool ReadEAN8 ;
	bool ReadMicroPDF417;
	bool ReadNumeric;
	bool ReadPDF417 ;
	bool ReadPatchCodes;
	bool ReadShortCode128;
	bool ReadUPCA ;
	bool ReadUPCE ;
	int ScanDirection;
	int ShortCode128MinLength;
	bool ShowCheckDigit;
	int ShowCodabarStartStop;
	int SkewLineJump;
	int SkewTolerance;
	bool UseOldCode128Algorithm;
	bool UseOverSampling;
	bool UseRunCache;
	bool WeightLongerBarcodes;
	
	// Properties that are specific to this class
	bool WaitForFocus;
	NSString *BarcodeValue ;
	NSString *BarcodeType ;
	UIViewController *Delegate ;
	UIImagePickerController * picker;
	NSTimer *scanTimer;
	UIButton *CancelButton ;
	UIButton *TestButton ;
	UIView	*ViewForPreview ;
	UIImageView *BackgroundImageView ;
	UIImageView *OverlayImageView ;
	UIImage *BackgroundImage ;
	UIImage *OverlayImage ;
	UIImageView *TestImageView ;
	UIImage *TestImage ;
	bool haveReadBarcode ;
	bool AutoRotate ;
	bool haveDonePreviewSetup ;
	void *hBarcode ;
#if ! TARGET_IPHONE_SIMULATOR
	AVCaptureSession *Session ;
	AVCaptureDevice *Device ;
	AVCaptureVideoPreviewLayer *PreviewLayer;
#endif	
}

// Private methods
- (void) GetProperties;
- (void) SetProperties;
- (int) ScanBarcodeFromBitmap:(CGImageRef) inImage;
- (void) sendNotification: (NSString *)name;
- (void) setBarcodeValue: (NSString *) input;
- (void) setBarcodeType: (NSString *) input;
- (void) removeViews;
- (void) addViews;
- (void) setCancelButton: (UIButton *) input;
- (void) setTestButton: (UIButton *) input;
- (void) setupPreview;
- (UIViewController*) getViewController;
- (void) emptyResults;
- (void)setupCaptureSession;
- (void) cleanUpVideoCapture ;
- (void) captureSuccess ;
- (void) showIdleState ;
- (void) showBusyState ;
- (void)	restoreImageView: (UIImageView *) view
			  Orientation: (UIInterfaceOrientation) orientation;

// Methods to enable the setting of Softek Barcode Reader SDK properties
- (void) setAllowDuplicateValues: (bool) input;
- (void) setBitmapResolution: (int) input;
- (void) setCodabarMaxVariance: (int) input;
- (void) setCode25Checksum: (bool) input;
- (void) setCode39Checksum: (bool) input;
- (void) setCode39NeedStartStop: (bool) input;
- (void) setColorChunks: (int) input;
- (void) setColorProcessingLevel: (int)input;
- (void) setColorThreshold: (int) input;
- (void) setConvertUPCEToEAN13: (bool) input;
- (void) setDatabarOptions: (int) input;
- (void) setDespeckle: (bool) input;
- (void) setEncoding: (int) input;
- (void) setErrorCorrection: (bool) input;
- (void) setExtendedCode39: (bool) input;
- (void) setGammaCorrection: (int) input;
- (void) setLicenseKey: (NSString *)input;
- (void) setLineJump: (int) input;
- (void) setMaxLength: (int)input;
- (void) setMedianFilter: (bool) input;
- (void) setMinLength: (int)input;
- (void) setMinOccurrence: (int) input;
- (void) setMinSpaceBarWidth: (int) input;
- (void) setMultipleRead: (bool) input;
- (void) setNoiseReduction: (bool) input;
- (void) setPageNo: (int) input;
- (void) setPatchCodeMinOccurrence: (int) input;
- (void) setPattern: (NSString *)input;
- (void) setPdf417Debug: (bool) input;
- (void) setPhotometric: (int) input;
- (void) setPrefOccurrence: (int) input;
- (void) setQuietZoneSize: (int) input;
- (void) setReadCodabar: (bool)input;
- (void) setReadCode128: (bool)input;
- (void) setReadCode25: (bool)input;
- (void) setReadCode25ni: (bool)input;
- (void) setReadCode39: (bool)input;
- (void) setReadCode93: (bool) input;
- (void) setReadDatabar: (bool)input;
- (void) setReadDatamatrix: (bool)input;
- (void) setReadQRCode: (bool)input;
- (void) setReadEAN13: (bool)input;
- (void) setReadEAN8: (bool)input;
- (void) setReadMicroPDF417: (bool) input;
- (void) setReadNumeric: (bool) input;
- (void) setReadPDF417: (bool)input;
- (void) setReadPatchCodes: (bool) input;
- (void) setReadShortCode128: (bool) input;
- (void) setReadUPCA: (bool)input;
- (void) setReadUPCE: (bool)input;
- (void) setScanDirection: (int) input;
- (void) setShortCode128MinLength: (int) input;
- (void) setShowCheckDigit: (bool) input;
- (void) setShowCodabarStartStop: (int) input;
- (void) setSkewLineJump: (int) input;
- (void) setSkewTolerance: (int) input;
- (void) setUseOldCode128Algorithm: (bool) input;
- (void) setUseOverSampling: (bool) input;
- (void) setUseRunCache: (bool) input;
- (void) setWeightLongerBarcodes: (bool) input;

// Methods of the Softek Barcode Reader SDK
- (bool) LoadXMLSettings: (NSString *) input;

// Methods specific to the iphone interface
- (void) setDelegate: (UIViewController *)input;
- (void) ScanBarcodeFromCameraRoll;
- (void) ScanBarcodeFromViewFinder;
- (void) ScanBarcodeFromCamera;
- (void) setViewForPreview:(UIView *)input;
- (void) setBackgroundImageView:(UIImageView *)input ;
- (void) setOverlayImageView:(UIImageView *)input ;
- (void) setTestImageView:(UIImageView *)input ;
- (void) setBackgroundImage:(UIImage *)input ;
- (void) setOverlayImage:(UIImage *)input ;
- (void) setTestImage:(UIImage *)input ;
- (void) setWaitForFocus: (bool)input;
- (UIView *) getViewForPreview;
- (void) ResizePreview;
- (NSString*) BarcodeValue ;
- (NSString*) BarcodeType ;
- (UIViewController*) Delegate ;


#if ! TARGET_IPHONE_SIMULATOR
- (void)captureOutput:(AVCaptureOutput *)captureOutput 
	didOutputSampleBuffer:(CMSampleBufferRef)sampleBuffer 
	   fromConnection:(AVCaptureConnection *)connection;
- (CGImageRef) imageFromSampleBuffer:(CMSampleBufferRef) sampleBuffer;
- (void) setSession: (AVCaptureSession *) input;
- (void) setDevice: (AVCaptureDevice *) input;
- (void) setPreviewLayer: (AVCaptureVideoPreviewLayer *) input;
#endif

@end

@interface NSObject(NSWindowNotifications)
- (void)BardecodeDidFinish:(NSNotification*)notification;
@end
